# Assets

In the Syclops context, assets can be a variety of things. This includes 3D models, textures or materials. The following sections will explain how to use assets in Syclops.

## Asset Library
Assets are usually grouped together as a library and defined in a YAML file. The following example shows how to define an asset library:


```yaml title="Example Asset Library"
name: Example Asset Library
description: This is an example asset library

assets:
    My Example Object:
        type: model
        tags: [example]
        filepath: my_first_asset.obj # (1)!
    My Example Environment Texture:
        type: environment_texture
        tags: [sunny]
        filepath: textures/my_sunny_environment.hdr # (2)!
```

1.  Relative to the asset library file.
2.  Relative to the asset library file.

!!! note 
    Paths are always written relative to the asset library file.

An asset is referenced by its library and unique name. Referencing the "My Example Object" would look like this: `Example Asset Library/My Example Object`.



## Different Asset Types
=== "Model"
    Models are used to create 3D objects in the scene.
    ```yaml title="Model Asset"
    <asset_name>:
        type: model
        filepath: <path_to_model>
    ```
=== "Texture"
    Textures are mostly used to control things like density of scatter objects, height of the ground plane, or drive other parameters of the scene.
    ```yaml title="Texture Asset"
    <asset_name>:
        type: texture
        filepath: <path_to_texture>
    ```
=== "PBR Texture"
    PBR Textures are used for photorealistic rendering of objects. Currently they are only supported for the ground plane.
    ```yaml title="PBR Texture Asset"
    <asset_name>:
        type: pbr_texture
        texture_size: <texture_size> # (1)!
        texture_displacement_scale: <texture_displacement_scale> # (2)!
        diffuse_filepath: <diffuse_texture_filepath>
        normal_filepath: <normal_texture_filepath>
        roughness_filepath: <roughness_texture_filepath>
        displacement_filepath: <displacement_texture_filepath>
    ```

    1.  The size of the texture in meters.
    2.  Scale value to change effect of displacement map. Usually ~0.05.
=== "Environment Texture"
    Environment Textures are used to light the scene and create a backdrop.
    ```yaml title="Environment Texture Asset"
    <asset_name>:
        type: environment_texture
        filepath: <environment_texture_filepath>
    ```

!!! info
    Each asset can have additional information that is either autogenerated or manually added. This includes the following attributes:

    |Attribute|Description|
    |:---:|:---:|
    |**tags**|Additional tags for the object|
    |**license**|License of the asset|
    |**thumbnail**|List of thumbnail paths (autogenerated)|
    |<b>*_md5</b>|MD5 hash of the asset file (autogenerated)|


## Installing New Assets

By running `syclops -c`, the pipeline crawls for asset library YAML files in all subdirectories of the paths defined in `<install_dir>/asset_paths.yaml`. Afterwards, a large asset catalog is created in the install directory. This catalog is used by the pipeline during runtime for asset lookup. With the catalog created, you can now reference assets in your scene files with `asset_library_name/asset_name`.

!!! note
    The asset catalog is only updated when running `syclops -c`. If you add new assets, you have to run this command again.